[![PyPI Shield](https://img.shields.io/pypi/v/ballet.svg)](https://pypi.python.org/pypi/ballet)
[![Travis CI Shield](https://travis-ci.org/HDI-Project/ballet.svg?branch=master)](https://travis-ci.org/HDI-Project/ballet)

# ballet

A **light**weight framework for collaborative data science projects with a focus on **feat**ure engineering.

*ballet* defines robust `Feature` and `FeaturePipeline` objects built
alongside the `sklearn_pandas` project, as well as providing a host of other functionality.

*ballet.eng* is a library of versatile transformers for feature engineering built
on top of the base `Feature` abstraction.

- Free software: MIT license
- Documentation: https://hdi-project.github.io/ballet
- Homepage: https://github.com/HDI-Project/ballet
